asr.test.test\_setup\_magnetize
===============================

.. automodule:: asr.test.test_setup_magnetize

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_setup_magnetize
   .. autofunction:: test_setup_magnetize_state_inputs
   
   

   
   
   

   
   
   